#!/usr/bin/env python

from distutils.core import setup
setup(name='pyleapcard',
      version='0.1.0',
      description='Python Leap Card API',
      author='Jack Higgins',
      author_email='pypi@jackhiggins.ie',
      url='https://github.com/skhg/pyleapcard',
      py_modules=['pyleapcard'],
      license='MIT'
      )